import logging
from typing import Any

import configargparse

config = None


def get_config() -> Any:
    parser = configargparse.get_argument_parser(
        config_file_parser_class=configargparse.YAMLConfigFileParser,
        formatter_class=configargparse.ArgumentDefaultsHelpFormatter,
    )

    parser.add_argument(
        "--debug", action="store_true", default=False, help="debugging mode"
    )
    parser.add_argument("--dry-run", action="store_true", default=False, help="dryrun")
    parser.add_argument(
        "-c", "--config", required=False, is_config_file=True, help="config file path"
    )
    parser.add_argument(
        "--local", required=False, is_config_file=True, help="local config file path"
    )

    parser.add_argument(
        "--config-save",
        required=False,
        is_write_out_config_file_arg=True,
        help="config file path",
    )
    parser.add_argument(
        "--push-url", default="http://echo.free.beeceptor.com/sample-request"
    )
    parser.add_argument("--push-timeout", type=int, default=5)
    parser.add_argument("--push-frequency", type=int, default=0, help="0 seconds to disable push status")
    parser.add_argument("--ws", default="ws://nexus:8082/ws")
    parser.add_argument("--realm", default="realm1")
    parser.add_argument(
        "--simulate-upgrade", default="", help="example: mev-fronted==1.0.0"
    )
    parser.add_argument("--upgrade", action="store_true", default=False, help="upgrade all packages to latest version")
    parser.add_argument("--leds", type=int, default=0, help="number of leds, default=3")
    parser.add_argument("--led-inverted", action="store_true", default=False, help="inverted led")
    #parser.add_argument("--packages", default="mev-fake,mev-yolodeep,mev-cerbero,mev-assets,mev-monitor", help="packages to upgrade")

    global config
    config, _ = parser.parse_known_args()
    logging.basicConfig(
        format="%(asctime)s [%(levelname)s] %(name)s %(message)s",
        level="DEBUG" if config.debug else "INFO",
    )
    if config.debug:
        import jurigged
        logging.getLogger('watchdog').setLevel(logging.INFO)
        jurigged.watch(pattern="*mev_monitor*.py")

    return config
